Built-in columns — django-tables2 2.0.0a3 documentation

# Built-in columns

For common use-cases the following columns are included:

- `BooleanColumn` -- renders boolean values
- `Column` -- generic column
- `CheckBoxColumn` -- renders `checkbox` form inputs
- `DateColumn` -- date formatting
- `DateTimeColumn` -- `datetime` formatting in the local timezone
- `EmailColumn` -- renders `<a href="mailto:...">` tags
- `FileColumn` -- renders files as links
- `JSONColumn` -- renders JSON as an indented string in `<pre></pre>`
- `LinkColumn` -- renders `<a href="...">` tags (compose a Django URL)
- `ManyToManyColumn` -- renders a list objects from a `ManyToManyField`
- `RelatedLinkColumn` -- renders `<a href="...">` tags linking related objects
- `TemplateColumn` -- renders template code
- `URLColumn` -- renders `<a href="...">` tags (absolute URL)